@@ -1,8 +1,4 @@
-use lambda_http::{
-    handler,
-    lambda_runtime::{self, Context, Error},
-    IntoResponse, Request, RequestExt, Response,
-};
+use lambda_http::{service_fn, Error, IntoResponse, Request, RequestExt, Response};
 
 struct SharedClient {
     name: &'static str,
@@ -23,9 +19,11 @@ async fn main() -> Result<(), Error> {
     let shared_client_ref = &shared_client;
 
     // Define a closure here that makes use of the shared client.
-    let handler_func_closure = move |event: Request, ctx: Context| async move {
-        Ok(match event.query_string_parameters().get("first_name") {
-            Some(first_name) => shared_client_ref.response(ctx.request_id, first_name).into_response(),
+    let handler_func_closure = move |event: Request| async move {
+        Ok(match event.query_string_parameters().first("first_name") {
+            Some(first_name) => shared_client_ref
+                .response(event.lambda_context().request_id, first_name)
+                .into_response(),
             _ => Response::builder()
                 .status(400)
                 .body("Empty first name".into())
@@ -34,6 +32,6 @@ async fn main() -> Result<(), Error> {
     };
 
     // Pass the closure to the runtime here.
-    lambda_runtime::run(handler(handler_func_closure)).await?;
+    lambda_http::run(service_fn(handler_func_closure)).await?;
     Ok(())
 }
